@@ -1,22 +1,39 @@
 package Tee;
 
-$Tee::VERSION     = '0.13_51';
-$Tee::VERSION     = eval $Tee::VERSION; ## no critic
-@Tee::ISA         = qw (Exporter);
-@Tee::EXPORT      = qw (tee);
+$VERSION     = "0.10";
+@ISA         = qw (Exporter);
+@EXPORT      = qw (tee);
 
 use strict;
 use Exporter ();
+use File::Spec;
 use Probe::Perl;
 # use warnings; # only for Perl >= 5.6
 
+use constant PTEE => "ptee";
 
 #--------------------------------------------------------------------------#
 # Platform independent ptee invocation
 #--------------------------------------------------------------------------#
 
-my $perl = Probe::Perl->find_perl_interpreter;
-my $ptee_cmd = "$perl -MTee::App -e run --";
+my $p = Probe::Perl->new;
+my $perl = $p->find_perl_interpreter;
+my $ptee_cmd;
+my $to_devnull = " > " . File::Spec->devnull . " 2>&1";
+for my $path ( split($p->config('path_sep'), $ENV{PATH}) ) {
+    my $try_ptee = File::Spec->catfile( $path, PTEE );
+    next unless -r $try_ptee;
+    if ( system("$try_ptee -V $to_devnull" ) == 0 ) {
+        $ptee_cmd = $try_ptee;
+        last;
+    }
+    if ( system("$perl $try_ptee -V $to_devnull") == 0 ) {
+        $ptee_cmd = "$perl $try_ptee";
+        last;
+    }
+}
+
+die "Couldn't find a working " . PTEE . "\n" unless $ptee_cmd;
 
 #--------------------------------------------------------------------------#
 # Functions
@@ -26,10 +43,10 @@ sub tee {
     my $command = shift;
     my $options;
     $options = shift if (ref $_[0] eq 'HASH');
-    my $files = join(" ", @_);
+    my $file = shift;
     my $redirect = $options->{stderr} ? " 2>&1 " : q{};
     my $append = $options->{append} ? " -a " : q{};
-    system( "$command $redirect | $ptee_cmd $append $files" );
+    system( "$command $redirect | $ptee_cmd $append $file" );
 }
 
 1; # modules must be true
@@ -45,10 +62,6 @@ __END__
 
 Tee - Pure Perl emulation of GNU tee
 
-= VERSION
-
-This documentation refers to version %%VERSION%%
-
 = SYNOPSIS
 
  # from Perl
@@ -104,13 +117,13 @@ same time.
 
 * [ptee]
 * IPC::Run3
-* IO::Tee
 
 = BUGS
 
 Please report any bugs or feature using the CPAN Request Tracker.  
-Bugs can be submitted through the web interface at 
-[http://rt.cpan.org/Dist/Display.html?Queue=Tee]
+Bugs can be submitted by email to C<bug-Tee@rt.cpan.org> or 
+through the web interface at 
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Tee>
 
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
@@ -119,24 +132,43 @@ existing test-file that illustrates the bug or desired feature.
 
 David A. Golden (DAGOLDEN)
 
+dagolden@cpan.org
+
+http://www.dagolden.org/
+
 = COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2008 by David A. Golden. All rights reserved.
+Copyright (c) 2006 by David A. Golden
 
-Licensed under Apache License, Version 2.0 (the "License").
-You may not use this file except in compliance with the License.
-A copy of the License was distributed with this file or you may obtain a 
-copy of the License from http://www.apache.org/licenses/LICENSE-2.0
+This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
 
-Files produced as output though the use of this software, shall not be
-considered Derivative Works, but shall be considered the original work of the
-Licensor.
+The full text of the license can be found in the
+LICENSE file included with this module.
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+
+= DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =end wikidoc
 
